@@ -39,7 +39,7 @@ int main(int argc, char** argv)
     // see if we are starting with session management
     if (app.isSessionRestored())
     {
-        RESTORE(Shell);
+        kRestoreMainWindows<Shell>();
     }
     else
     {
